==> oer-0.0.1-20190731.023331-5-sources.jar: com/xdja/pki/itsca/oer/asn1/SequenceOfRectangularRegion.java <==
package com.xdja.pki.itsca.oer.asn1;

import com.xdja.pki.itsca.oer.asn1.base.SequenceOf;
import com.xdja.pki.itsca.oer.utils.ByteArrayUtils;
import org.bouncycastle.util.BigIntegers;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;

/***
 *
 * SequenceOfRectangularRegion ::= SEQUENCE OF RectangularRegion
 *
 */
public class SequenceOfRectangularRegion extends SequenceOf {

    private static Logger logger = LoggerFactory.getLogger(SequenceOfRectangularRegion.class);
    public void addRectangularRegion(RectangularRegion rectangularRegion) {
        super.addOERObject(rectangularRegion);
    }
    private List<RectangularRegion> rectangularRegions = new ArrayList<>();

    public List<RectangularRegion> getRectangularRegions() {
        return rectangularRegions;
    }

    public void setRectangularRegions(RectangularRegion itsAidSsp) {
        this.rectangularRegions.add(itsAidSsp);
    }

    public static SequenceOfRectangularRegion getInstance(byte[] data) throws Exception {
        ByteArrayUtils.printHexBinary(logger, "SequenceOfRectangularRegion start data ", data);
        BigInteger len = BigIntegers.fromUnsignedByteArray(data, 0, 1);
        BigInteger length = BigIntegers.fromUnsignedByteArray(data, 1, len.intValue());
        byte[] goal = new byte[data.length - 2];
        System.arraycopy(data, 2, goal, 0, goal.length);
        SequenceOfRectangularRegion sequenceOfRectangularRegion = new SequenceOfRectangularRegion();
        for (int i = 0; i < length.intValue(); i++) {
            RectangularRegion instance = RectangularRegion.getInstance(goal);
            goal = instance.getGoal();
            sequenceOfRectangularRegion.addRectangularRegion(instance);
            sequenceOfRectangularRegion.setRectangularRegions(instance);
            ByteArrayUtils.printHexBinary(logger, "SequenceOfRectangularRegion  at index" + i + "RectangularRegion data ", instance.getEncode());
        }
        sequenceOfRectangularRegion.setGoal(goal);
        ByteArrayUtils.printHexBinary(logger, "SequenceOfRectangularRegion lave data ", goal);
        return sequenceOfRectangularRegion;
    }
}

==> oer-0.0.2-20190819.074155-10-sources.jar: com/xdja/pki/itsca/oer/asn1/SequenceOfRectangularRegion.java <==
package com.xdja.pki.itsca.oer.asn1;

import com.xdja.pki.itsca.oer.asn1.base.SequenceOf;
import com.xdja.pki.itsca.oer.utils.ByteArrayUtils;
import org.bouncycastle.util.BigIntegers;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;

/***
 *
 * SequenceOfRectangularRegion ::= SEQUENCE OF RectangularRegion
 *
 */
public class SequenceOfRectangularRegion extends SequenceOf {

    private static Logger logger = LoggerFactory.getLogger(SequenceOfRectangularRegion.class);

    public void addRectangularRegion(RectangularRegion rectangularRegion) {
        super.addOERObject(rectangularRegion);
    }

    private List<RectangularRegion> rectangularRegions = new ArrayList<>();

    public List<RectangularRegion> getRectangularRegions() {
        return rectangularRegions;
    }

    public void setRectangularRegions(RectangularRegion regions) {
        this.rectangularRegions.add(regions);
    }

    public static SequenceOfRectangularRegion getInstance(byte[] data) throws Exception {
        ByteArrayUtils.printHexBinary(logger, "SequenceOfRectangularRegion start data ", data);
        BigInteger len = BigIntegers.fromUnsignedByteArray(data, 0, 1);
        BigInteger length = BigIntegers.fromUnsignedByteArray(data, 1, len.intValue());
        byte[] goal = new byte[data.length - 2];
        System.arraycopy(data, 2, goal, 0, goal.length);
        SequenceOfRectangularRegion sequenceOfRectangularRegion = new SequenceOfRectangularRegion();
        for (int i = 0; i < length.intValue(); i++) {
            RectangularRegion instance = RectangularRegion.getInstance(goal);
            goal = instance.getGoal();
            sequenceOfRectangularRegion.addRectangularRegion(instance);
            sequenceOfRectangularRegion.setRectangularRegions(instance);
            ByteArrayUtils.printHexBinary(logger, "SequenceOfRectangularRegion  at index" + i + "RectangularRegion data ", instance.getEncode());
        }
        sequenceOfRectangularRegion.setGoal(goal);
        ByteArrayUtils.printHexBinary(logger, "SequenceOfRectangularRegion lave data ", goal);
        return sequenceOfRectangularRegion;
    }
}
